@@ -472,7 +472,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                     params = ['|'.join(patterns)])
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
-        self.ND = neighCount
+        self.ND = nd
         self.FWND = fwnd
         self.save()
         return self.ND,self.FWND
